@@ -6,7 +6,7 @@ use strict;
 use CPANPLUS::Dist::Base   qw();
 use Exporter               qw(import);
 
-our $VERSION     = '1.29';
+our $VERSION     = '1.30';
 our @EXPORT      = qw();
 our @EXPORT_OK   = qw(dist_pkgname dist_pkgver);
 our %EXPORT_TAGS = ( 'all' => [ @EXPORT_OK ] );
@@ -1499,7 +1499,14 @@ sub _prepare_pkgdesc
         $pkgdesc = $pkgdesc_src->( $module ) and last PKGDESC_LOOP;
     }
 
-    return $status->pkgdesc( $pkgdesc || q{} );
+    if ( $pkgdesc ) {
+        # Avoid CR chars because of CRLF line endings in sources.
+        $pkgdesc =~ tr/\r//d;
+    } else {
+        $pkgdesc = q{};
+    }
+    $status->pkgdesc( $pkgdesc );
+    return;
 }
 
 #----------------------------
@@ -1634,11 +1641,9 @@ sub _prepare_status
 sub _get_disturl
 {
     croak 'Invalid arguments to _get_disturl method' if @_ != 1;
-    my $self   = shift;
-    my $module = $self->parent;
-
-    my $distname  = $module->package_name;
-    return join '/', $CPANURL, 'dist', $distname;
+    my $self = shift;
+    my $dist = $self->parent->package_name;
+    return "https://metacpan.org/release/$dist";
 }
 
 #---INSTANCE METHOD---
